@@ -6,6 +6,7 @@ import os
 import re
 import datetime as dtmod
 from datetime import datetime
+from operator import attrgetter
 from unicodedata import normalize
 from urllib.parse import urljoin
 from collections.abc import Container
@@ -23,14 +24,12 @@ def slugify(string):
     """
     Slugify *s*.
     """
-
     string = normalize("NFKD", str(string))
     string = re.sub(r"[^\w\s-]", "", string).strip().lower()
     return re.sub(r"[-\s]+", "-", string)
 
 
 def os_path_join(path, *paths):
-
     return os.path.join(path, *paths).replace(os.path.sep, "/")
 
 
@@ -61,7 +60,6 @@ def require_config_str_or_list_lookup(lookup_config_key, is_optional=True):
             value = [value]
         if not isinstance(value, list):
             raise KeyError(key + " must be a str or list")
-
         allowed_values = config[lookup_config_key]
         for v in value:
             if v not in allowed_values:
@@ -125,14 +123,12 @@ CONFIG = [
     ("disqus_pages", False, True),
     ("blog_post_pattern", [], True, require_config_type((str, list))),
 ]
-
 TOMORROW = datetime.today() + dtmod.timedelta(1)
 TOMORROW = TOMORROW.replace(hour=0, minute=0, second=0, microsecond=0)
 FUTURE = datetime(9999, 12, 31)
 
 
 def revise_pending_xrefs(doctree, docname):
-
     for node in doctree.traverse(addnodes.pending_xref):
         node["refdoc"] = docname
 
@@ -141,9 +137,6 @@ def link_posts(posts):
     """
     Link posts after sorting them post by published date.
     """
-
-    from operator import attrgetter
-
     posts = filter(attrgetter("order"), posts)
     posts = sorted(posts)
     posts[0].prev = posts[-1].next = None
@@ -162,7 +155,6 @@ class Blog(Container):
     _dict = {}
 
     def __init__(self, app):
-
         self.__dict__ = self._dict
         if not self._dict:
             self._init(app)
@@ -171,12 +163,9 @@ class Blog(Container):
         """
         Instantiate Blog.
         """
-
         self.app = app
         self.config = {}
-
         self.references = refs = {}
-
         # get configuration from Sphinx app
         for opt in CONFIG:
             try:
@@ -190,48 +179,37 @@ class Blog(Container):
                 else getattr(app.config, opt[0])
             )
             self.config[opt[0]] = value
-
         # blog catalog contains all posts
         self.blog = Catalog(self, "blog", "blog", None)
-
         # contains post collections by year
         self.archive = Catalog(self, "archive", "archive", None, reverse=True)
         self.archive.docname += "/archive"
         refs["blog-archives"] = (self.archive.docname, "Archives")
-
         self.catalogs = cat = {}  # catalogs of user set labels
         self.tags = cat["tags"] = Catalog(self, "tags", "tag", "tag")
         refs["blog-tags"] = (self.tags.docname, "Tags")
-
         self.author = cat["author"] = Catalog(self, "author", "author", "author")
         refs["blog-authors"] = (self.author.docname, "Authors")
-
         self.location = cat["location"] = Catalog(self, "location", "location", "location")
         refs["blog-locations"] = (self.location.docname, "Locations")
-
         self.language = cat["language"] = Catalog(self, "language", "language", "language")
         refs["blog-languages"] = (self.language.docname, "Languages")
-
         self.category = cat["category"] = Catalog(self, "category", "category", "category")
         refs["blog-categories"] = (self.category.docname, "Categories")
-
         for catname in ["author", "location", "language"]:
             catalog = self.catalogs[catname]
             items = self.config["blog_" + catname + "s"].items()
             for label, (name, link) in items:
                 catalog[label] = Collection(catalog, label, name, link)
-
         self.posts = self.blog["post"] = Collection(self.blog, "post", "Posts", path=self.blog_path)
         self.drafts = self.blog["draft"] = Collection(
             self.blog, "draft", "Drafts", path=os_path_join(self.blog_path, "drafts")
         )
-
         # add references to posts and drafts
         # e.g. :ref:`blog-posts`
         refs["blog-posts"] = (self.config["blog_path"], "Posts")
         refs["blog-drafts"] = (os_path_join(self.config["blog_path"], "drafts"), "Drafts")
         refs["blog-feed"] = (os_path_join(self.config["blog_path"], "atom.xml"), self.blog_title + " Feed")
-
         # set some internal configuration options
         self.config["fontawesome"] = (
             self.config["fontawesome_included"]
@@ -240,7 +218,6 @@ class Blog(Container):
         )
 
     def __getattr__(self, name):
-
         try:
             attr = self.config[name]
         except KeyError:
@@ -248,19 +225,15 @@ class Blog(Container):
         return attr
 
     def __getitem__(self, key):
-
         return self.posts[key] or self.drafts[key]
 
     def __contains__(self, item):
-
         return item in self.posts or item in self.drafts
 
     def __len__(self):
-
         return len(self.posts)
 
     def __nonzero__(self):
-
         return len(self) > 0
 
     @property
@@ -268,14 +241,12 @@ class Blog(Container):
         """
         RSS feed page name.
         """
-
         return os_path_join(self.blog_path, "atom.xml")
 
     def register(self, docname, info):
         """
         Register post *docname*.
         """
-
         post = Post(self, docname, info)
         if post.date and post.date < TOMORROW:
             self.posts.add(post)
@@ -288,7 +259,6 @@ class Blog(Container):
         """
         Yield *num* recent posts, excluding the one with `docname`.
         """
-
         if num is None:
             num = len(self)
         for i, post in enumerate(self.posts):
@@ -305,7 +275,6 @@ class Blog(Container):
 
         Return value is used as disqus page identifier.
         """
-
         if self.config["blog_baseurl"]:
             if pagename.endswith("index"):
                 pagename = pagename[:-5]
@@ -320,7 +289,6 @@ class Blog(Container):
         When found, :file:`index.html` is trimmed from the end of the
         URL.
         """
-
         if self.config["blog_baseurl"]:
             url = urljoin(self.config["blog_baseurl"], pagename)
             if url.endswith("index"):
@@ -333,10 +301,8 @@ def html_builder_write_doc(self, docname, doctree):
     Part of :meth:`sphinx.builders.html.StandaloneHTMLBuilder.write_doc` method
     used to convert *doctree* to HTML.
     """
-
     destination = StringOutput(encoding="utf-8")
     doctree.settings = self.docsettings
-
     self.secnumbers = {}
     self.imgpath = relative_uri(self.get_target_uri(docname), "_images")
     self.dlpath = relative_uri(self.get_target_uri(docname), "_downloads")
@@ -351,7 +317,6 @@ class BlogPageMixin:
         return self.title
 
     def __repr__(self):
-
         return str(self) + " <" + str(self.docname) + ">"
 
     @property
@@ -359,12 +324,10 @@ class BlogPageMixin:
         """
         Reference to :class:`~ablog.blog.Blog` object.
         """
-
         return self._blog
 
     @property
     def title(self):
-
         return getattr(self, "name", getattr(self, "_title"))
 
 
@@ -374,7 +337,6 @@ class Post(BlogPageMixin):
     """
 
     def __init__(self, blog, docname, info):
-
         self._blog = blog
         self.docname = docname
         self.section = info["section"]
@@ -411,7 +373,6 @@ class Post(BlogPageMixin):
             self.location = info.get("location")
             self.language = info.get("language")
             self.archive = []
-
         self.redirect = info.get("redirect")
         self.options = info
 
@@ -456,7 +417,6 @@ class Post(BlogPageMixin):
         """
         Next published post in chronological order.
         """
-
         if self._next == -1:
             link_posts(self._blog.posts)
         return self._next
@@ -466,7 +426,6 @@ class Post(BlogPageMixin):
         """
         Set next published post in chronological order.
         """
-
         self._next = post
 
     @property
@@ -474,7 +433,6 @@ class Post(BlogPageMixin):
         """
         Previous published post in chronological order.
         """
-
         if self._prev == -1:
             link_posts(self._blog.posts)
         return self._prev
@@ -484,7 +442,6 @@ class Post(BlogPageMixin):
         """
         Set previous published post in chronological order.
         """
-
         self._prev = post
 
 
@@ -494,7 +451,6 @@ class Catalog(BlogPageMixin):
     """
 
     def __init__(self, blog, name, xref, path, reverse=False):
-
         self._blog = blog
         self.name = name
         self.xref = xref  # for creating labels, e.g. `tag-python`
@@ -508,30 +464,24 @@ class Catalog(BlogPageMixin):
         self._reverse = reverse
 
     def __str__(self):
-
         return str(self.name)
 
     def __getitem__(self, name):
-
         try:
             return self.collections[name]
         except KeyError:
             return self.collections.setdefault(name, Collection(self, name))
 
     def __setitem__(self, name, item):
-
         self.collections[name] = item
 
     def __len__(self):
-
         return sum(len(coll) for coll in self)
 
     def __nonzero__(self):
-
         return len(self) > 0
 
     def __iter__(self):
-
         keys = list(self.collections)
         keys.sort(reverse=self._reverse)
         for key in keys:
@@ -542,7 +492,6 @@ class Catalog(BlogPageMixin):
         Add post to appropriate collection(s) and replace collections labels
         with collection objects.
         """
-
         colls = []
         for label in getattr(post, self.name, []):
             coll = self[label]
@@ -555,7 +504,6 @@ class Catalog(BlogPageMixin):
         """
         Return minimum and maximum sizes of collections.
         """
-
         if self._coll_lens is None or len(self._coll_lens) != len(self.collections):
             self._coll_lens = [len(coll) for coll in self.collections.values() if len(coll)]
             self._min_max = min(self._coll_lens), max(self._coll_lens)
@@ -568,7 +516,6 @@ class Collection(BlogPageMixin):
     """
 
     def __init__(self, catalog, label, name=None, href=None, path=None, page=0):
-
         self._catalog = catalog
         self._blog = catalog.blog
         self.label = label
@@ -581,55 +528,53 @@ class Collection(BlogPageMixin):
         self.xref = self.catalog.xref + "-" + slugify(label)
         self._slug = None
         self._html = None
-
         self._catalog.blog.references[self.xref] = (self.docname, self.name)
 
     def __str__(self):
-
         return str(self.name)
 
     def __len__(self):
-
         return len(self._posts)
 
     def __nonzero__(self):
-
         return len(self) > 0
 
     def __unicode__(self):
-
         return str(self.name)
 
     def __iter__(self):
-
         if self._posts_iter is None:
             posts = list(self._posts.values())
             posts.sort(reverse=True)
             self._posts_iter = posts
-
         yield from self._posts_iter
 
     def __getitem__(self, key):
-
         return self._posts.get(key)
 
     def __contains__(self, item):
-
         return item in self._posts
 
+    def __eq__(self, other):
+        return self.name == other.name
+
+    def __lt__(self, other):
+        return self.name < other.name
+
+    def __gt__(self, other):
+        return self.name > other.name
+
     @property
     def catalog(self):
         """
         :class:`~ablog.blog.Catalog` that the collection belongs to.
         """
-
         return self._catalog
 
     def add(self, post):
         """
         Add post to the collection.
         """
-
         post_name = post.docname
         if post.section:
             post_name += "#" + post.section
@@ -639,13 +584,10 @@ class Collection(BlogPageMixin):
         """
         Relative size used in tag clouds.
         """
-
         min_, max_ = self.catalog._minmax()
-
         diff = maxsize - minsize
         if len(self.catalog) == 1 or min_ == max_:
             return int(round(diff / 2.0 + minsize))
-
         size = int(1.0 * (len(self) - min_) / (max_ - min_) * diff + minsize)
         return size
 
@@ -654,7 +596,6 @@ class Collection(BlogPageMixin):
         """
         Collection page document name.
         """
-
         if self._path is None:
             self._path = os_path_join(self.catalog.path, slugify(self.name))
         return self._path
